import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class WaitForAudioResult(ResultBase):
    def __init__(self, json1 , successMessage, failMessage):
        jsonObj = json.loads(json1)
        self.rightLevel = jsonObj["rightLevel"]
        self.leftLevel = jsonObj["leftLevel"]
        self.time = jsonObj["time"]
        ResultBase.__init__(self, True if self.time>=0 else False, successMessage, failMessage)

        if(self.success):
            return
        if("errorCode" in jsonObj):
            self.message = self.getMessageForErrorCode(self.message, jsonObj["errorCode"])


import sys
import json

from testwizard.commands_core import CommandBase
from .WaitForAudioResult import WaitForAudioResult

class WaitForAudioCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "WaitForAudio")

    def execute(self, level, timeout):
        if(level == None):
            raise Exception("level is required")
        if(timeout == None):
            raise Exception("timeout is required")

        requestObj = [level, timeout]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return WaitForAudioResult(response.read(), "WaitForAudio was successful", "WaitForAudio failed")